@@ -59,9 +59,31 @@ class Fs_directory_module_class extends Fs_module_class {
         $this->register_aggregate_object('domain',
             array(
                 'name' => 'Domain',
-                'dynamic' => false, /* Domain objs are not dynamic, childs (users) are */
+                'dynamic' => true,
                 'base_path' => $this->object_name() . '/domain',
                 'has_child' => true,
+                    'methods' => array(
+                            'create' => array(
+                                    'name' => 'Create',
+                                    'description' => 'Create a domain',
+                                    'request' => 'POST',
+                            ),
+                            'retrieve' => array(
+                                    'name' => 'Retrieve',
+                                    'description' => 'Retrieve a domain',
+                                    'request' => 'GET',
+                            ),
+                            'update' => array(
+                                    'name' => 'Update',
+                                    'description' => 'Update a domain',
+                                    'request' => 'POST',
+                            ),
+                            'delete' => array(
+                                    'name' => 'Delete',
+                                    'description' => 'Delete a domain',
+                                    'request' => 'POST',
+                            ),
+                    ),
             )
         );
 
@@ -240,26 +262,11 @@ class Fs_directory_module_class extends Fs_module_class {
         * @return 
                  */
     public function reload_generate_config(&$config_manager, $obj_type=null){
-        // Get domains
-        $domains = $this->domains();
-
-        // For all domains
-        foreach($domains as $domain){
-            // Handle domain's users
-            $this->generate_user_config($config_manager, $domain);
-        }
-        return parent::generate_config($config_manager);
+        return $this->generate_config($config_manager);
     }
     public function reload_clear_modified($obj_type=null)
     {
-        // Get domains
-        $domains = $this->domains();
-
-        // For all domains
-        foreach($domains as $domain){
-            // the hard way :)
-            Safe_object_serializer_class::get_serializer()->clear_modified($domain->object_name() , true);
-        }
+        return $this->clear_configuration_modified();
     }
     public function generate_user_config(&$config_manager, $domain){
         // Delete directory
@@ -288,8 +295,31 @@ class Fs_directory_module_class extends Fs_module_class {
             // Params section
             $xml_writer->startElement("params");
             $xml_writer->startElement("param");
-            $xml_writer->writeAttribute("name", 'password');
-            $xml_writer->writeAttribute("value", $cfg['password']);
+
+            $os = $this->node()->os();
+            //Escaping single-quotes within single-quoted strings for  bash script
+            $tmp_password = str_replace("'", "'\"'\"'",$cfg['password']);
+            $cmd = "nohup /usr/local/sng/bin/sng-digest-authentication '".$user->name() .':'. $domain->name() .':'. $tmp_password . "'";
+            $output = array();
+            //do not escape the ' again
+            $return_var = null;
+            $rc = $os->execute($cmd, $output, false, true, $return_var);
+            if($rc){
+                $hash_password = $output[0];
+            }else{
+                $config_manager->add_error(array(
+                        'module' => 'directory',
+                        'obj_type' => 'domain',
+                        'obj_name' => $domain->name(),
+                        'description' => 'Fail to generate digest authentication',
+                        'code' => $return_var
+                )
+                );
+            }
+            
+            
+            $xml_writer->writeAttribute("name", 'a1-hash');
+            $xml_writer->writeAttribute("value", $hash_password);
             $xml_writer->EndElement(); //end param tag
             
             // Add custom user params
@@ -325,7 +355,7 @@ class Fs_directory_module_class extends Fs_module_class {
             }
             $xml_writer->startElement("variable");
             $xml_writer->writeAttribute("name", 'user_context');
-            $xml_writer->writeAttribute("value", "domain-user-".$user->name()."@".$domain->name());
+            $xml_writer->writeAttribute("value", "user.".$user->name()."@".$domain->name());
             $xml_writer->EndElement(); //end variable tag
 
             // Add custom user variables
@@ -357,7 +387,7 @@ class Fs_directory_module_class extends Fs_module_class {
 
             $xml_writer->startElement("include");
             $xml_writer->startElement("context");
-            $xml_writer->writeAttribute("name", "domain-user-".$user->name()."@".$domain->name());
+            $xml_writer->writeAttribute("name", "user.".$user->name()."@".$domain->name());
 
             $xml_writer->startElement("extension");
             $xml_writer->writeAttribute("name", "transfer-to-profile");
@@ -368,17 +398,18 @@ class Fs_directory_module_class extends Fs_module_class {
 
             $xml_writer->startElement("action");
             $xml_writer->writeAttribute("application", "set");
-            if ($cfg['call-routing'] == 'default') {
+            
+            if ($cfg['call-routing'] == '__none__') {
                 /* set the sangoma routing context empty to let the profile context decide where to go */
-                $xml_writer->writeAttribute("data", "sangoma.routing_context=");
+                $xml_writer->writeAttribute("data", "sangoma_routing_context=");
             } else {
-                $xml_writer->writeAttribute("data", "sangoma.routing_context=" . $cfg['call-routing']);
+                $xml_writer->writeAttribute('data', 'sangoma_routing_context=routing.' . $cfg['call-routing']);
             }
             $xml_writer->endElement(); //end action tag
 
             $xml_writer->startElement("action");
             $xml_writer->writeAttribute("application", "transfer");
-            $xml_writer->writeAttribute("data", '$1 XML profile-${sofia_profile_name}');
+            $xml_writer->writeAttribute("data", '$1 XML profile.${sofia_profile_name}.ingress');
             $xml_writer->endElement(); //end action tag
 
 
@@ -409,5 +440,100 @@ class Fs_directory_module_class extends Fs_module_class {
         if(!$this->fs_app()->reloadxml()) return false;
         return parent::post_write_config();
     }
+    /**
+     * @brief
+     *
+     * @param[in out] $name
+     * @param[in out] $data
+     *
+     * @return
+     */
+    public function api_create_domain($name, $data=null) {
+        $domain = new Fs_domain_class($this->node(), $this->object_name().'/domain', $name);
+        $domain->configure();
+        if($data) {
+            $domain->set_data_values($data);
+        }
+        return $domain;
+    }
+    /**
+     * @brief
+     *
+     * @param[in out] $name
+     * @param[in out] $data
+     *
+     * @return
+     */
+    public function api_retrieve_domain($name, $data=null) {
+        $domains = $this->domains();
+        return $domains[$name];
+    }
+    /**
+     * @brief
+     *
+     * @param[in out] $name
+     * @param[in out] $data
+     *
+     * @return
+     */
+    public function api_update_domain($name, $data=null, &$output = null) {
+        $domain = $this->api_retrieve_domain($name);
+        if($domain) {
+            if ($domain->validate($data,$output)) {
+                if (true == $domain->save()) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+    /**
+     * @brief
+     *
+     * @param[in out] $name
+     * @param[in out] $data
+     *
+     * @return
+     */
+    public function api_delete_domain($name, $data=null, &$output = null) {
+        $domains = $this->domains();
+        if($domains[$name]) {
+            if($domains[$name]->can_dispose($output)) {
+                foreach ($domains[$name]->has_aggregate_objects(false, true) as $_type => $_definition){
+                    if($_definition['configurable']){
+                        foreach ($domains[$name]->get_aggregate_objects($_type) as $sub_obj_name => $sub_object) {
+                            $sub_object->dispose();
+                        }    
+                    }
+                }
+                return $domains[$name]->dispose();
+            }
+        }
+        return false;
+    }
+    
+    public function get_object_enum($type)
+    {
+        if($type == 'domain_user'){
+            if(!$this->_agg_obj_enum[$type]){
+                $this->_agg_obj_enum[$type] = array();
+                $domains = $this->domains ();
+                if($domains != null){
+                    $user_list = array();
+                    foreach ( $domains as $obj ) {
+                        $users = $obj->users();
+                        if($users != null){
+                            foreach ($users as $user){
+                                $this->_agg_obj_enum[$type] [$user->name() .'@'.$obj->name()] = $user->name() .'@'.$obj->name();
+                            }    
+                        }
+                    } 
+                }
+            }
+            return $this->_agg_obj_enum[$type];
+        }else{
+            return parent::get_object_enum($type);
+        }
+    }
 }
 ?>
