@@ -40,8 +40,10 @@ class Fs_media_profile_class extends Safe_configurable_object_class
         // HW codecs
         $this->_hw_codec_enum = array(
             'none' => '',
+            'PCMU@10i' => 'PCMU 10ms, PT=0',
             'PCMU@20i' => 'PCMU 20ms, PT=0',
             'PCMU@30i' => 'PCMU 30ms, PT=0',
+            'PCMA@10i' => 'PCMA 10ms, PT=8',
             'PCMA@20i' => 'PCMA 20ms, PT=8',
             'PCMA@30i' => 'PCMA 30ms, PT=8',
             'G729@20i' => 'G.729 20ms, PT=18',
