@@ -440,9 +440,16 @@ class Fs_sip_profile_class extends Safe_configurable_object_class
       
       $error_msg_2 ='';
       //check system port
+      $app_process_name = $this->node()->software()->application()->process_name();
+      $user_prog = "";
+
       foreach($ports as $port_item){
-          if(!$this->node()->os()->valid_ip_port($port_item['ip'], $port_item['port'], $port_item['type'], 'nsc')){
+          if(!$this->node()->os()->valid_ip_port($port_item['ip'], $port_item['port'], $port_item['type'], $app_process_name, $user_prog)){
+            // Are we running our process under known dbg process ?
+            $app_dbg_processes = array('valgrind');
+            if(!in_array($user_prog, $app_dbg_processes)){
               $error_msg_2 = " This port is already being used by another program. " ;
+            }
           }
       }
       if($error_msg == '' && $error_msg_2 == ''){
