@@ -149,7 +149,7 @@ class Nsc_domain_class extends Fs_domain_class
     }
     public function sip_profile_check($sip_profile){
         $prof_data = $this->get_data_values(false);
-        if($prof_data['forward-registration']){
+        if($prof_data['forward-registration'] == 'true'){
             return ($prof_data['registrar-profile'] == $sip_profile) ? true : false;
         }else{
             return false;
