@@ -214,7 +214,9 @@ class Nsc_sip_profile_class extends Fs_sip_profile_class
     {
         parent::configure_interoperability();
         $this->add_enum_field('lync-interop', 'Lync Interoperability', 'dropdown', 'false', $this->enable_disable_enum());
-        $this->set_field_help('lync-interop','Enable or Disable settings for Lync interoperability.');
+        $this->set_field_help('lync-interop','Enable or disable settings for Lync interoperability.');
+        $this->add_enum_field('allow-malformed-headers', 'Allow Malformed Headers', 'dropdown', 'false', $this->enable_disable_enum());
+        $this->set_field_help('allow-malformed-headers','Allow receiving malformed non-critical SIP headers available in dialplan via <b>sip_mh_[header_name]</b> channel variable.');
     }
     protected function configure_authentication()
     {
