@@ -1289,7 +1289,96 @@ function safe_format_bytes($bytes, $precision = 2) {
     $bytes /= (1 << (10 * $pow)); 
 
     return round($bytes, $precision) . ' ' . $units[$pow]; 
-} 
+}
+
+/**
+ *
+ * This method generate the key for aes encrypt
+ *
+ * @return string 16 byte key
+ */
+function safe_aes_getkey($data){
+    $key = substr(md5($data), 8, 16);
+    return $key;
+}
+/**
+ *
+ * This method pad the data to a certain length with "\0"
+ *
+ * @return string
+ */
+function safe_aes_pad($data){
+    $len = strlen($data);
+    $td = mcrypt_module_open(MCRYPT_RIJNDAEL_128, '', MCRYPT_MODE_CBC, '');
+    $size = mcrypt_enc_get_iv_size($td);
+    mcrypt_module_close($td);
+    $data  = str_pad($data, $size - $len % $size, "\0");
+    return $data;
+}
+/**
+ *
+ * This method encrypts data(AES)
+ *
+ * @return string with base64_encode
+ */
+function safe_aes_encrypt($data, $key) {
+    $data = safe_aes_pad($data);
+    $td = mcrypt_module_open(MCRYPT_RIJNDAEL_128, '', MCRYPT_MODE_CBC, '');
+    $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
+    mcrypt_generic_init($td, $key, $iv);
+    $encrypted = mcrypt_generic($td, $data);
+    mcrypt_generic_deinit($td);
+    mcrypt_module_close($td);
+    return base64_encode($iv . $encrypted);
+}
+/**
+ *
+ * This method decrypt data(AES)
+ *
+ * @return string
+ */
+function safe_aes_decrypt($data, $key) {
+    $data = base64_decode($data);
+    $td = mcrypt_module_open(MCRYPT_RIJNDAEL_128, '', MCRYPT_MODE_CBC, '');
+    $size = mcrypt_enc_get_iv_size($td);
+    $iv = mb_substr($data, 0, mcrypt_enc_get_iv_size($td)-1);
+    mcrypt_generic_init($td, $key, $iv);
+    $data = mb_substr($data, mcrypt_enc_get_iv_size($td)-1, mb_strlen($data));
+    $text = mdecrypt_generic($td, $data);
+    mcrypt_generic_deinit($td);
+    mcrypt_module_close($td);
+    return trim($text);
+}
+
+/* random string */
+function rand_string( $length ) {
+    $chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./';
+    $size = strlen( $chars );
+    for( $i = 0; $i < $length; $i++ ) {
+        $str .= $chars[ rand( 0, $size - 1 ) ];
+    }
+    return $str;
+}
+// hash type (from http://www.akkadia.org/drepper/SHA-crypt.txt)
+// 1 = MD5 //22 byte
+// 5 = SHA256//43 byte
+// 6 = SHA512//86 byte
+function safe_hash_password($data, $type = '1'){
+    $salt = rand_string(5);
+    $tmp_string = '$' . $type . '$' . $salt . '$';
+    return crypt($data, $tmp_string);
+}
+function safe_is_hash_password($data){
+    $tmp_array = explode('$' , $data );
+    $hash_len = array('1' => 22, '5' => 43, '6' => 86 );
+    if(count($tmp_array) == 4
+            && in_array($tmp_array[1], array_keys($hash_len))
+            && strlen($tmp_array[3]) == $hash_len[$tmp_array[1]]){
+        return true;
+    }
+    return false;
+}
+
 
 /* End of file safe_helper.php */
             
