@@ -312,6 +312,10 @@ if (!function_exists('form_dropdown')) {
 if (!function_exists('form_checkbox')) {
     function form_checkbox($data = '', $value = '', $checked = FALSE, $extra = '')
     {
+        //fix checkbox '[]' in have problem when set_data_values and validate
+        if (!is_array($data)){
+            $data = $data .'[]';
+        }
         $defaults = array(
             'type' => 'checkbox',
             'name' => ((!is_array($data)) ? $data : '') ,
