@@ -180,7 +180,7 @@ class Sng_network_route_class extends Safe_configurable_object_class
         return parent::summary($type, $long, 4);
     }
 
-    public function validate($data, $output)
+    public function validate($data, &$output)
     {
         // Run regular validation first
         $validate = parent::validate($data, $output);
@@ -192,6 +192,7 @@ class Sng_network_route_class extends Safe_configurable_object_class
         // 2/ if a gateway is specified, it must be on same subnet as interface
         $network_module = $this->node()->find_module_by_name('network');
         $routes = $network_module->api_retrieve_route();
+        $address = $this->get_data_value('address', false);
         foreach($routes as $route){
             // Skip ourself
             if($this->name() == $route->name()){
@@ -199,20 +200,27 @@ class Sng_network_route_class extends Safe_configurable_object_class
             }
             $route_data = $route->get_data_values(false);
             // 1/ check unique route
-            if($data['address'] == $route_data['address']){
+            if($address == $route_data['address']){
                 $validate = false;
-                $this->set_form_error('address', 'Destination already used by route '.$route->name());
+                $output['address']= 'Destination already used by route '.$route->name();
+                $this->set_form_error('address', $output['address']);
+                break;
             }
         }
         // 2/ check gateway
         if($data['gateway']){
+            $interface = $this->get_data_value('interface', false);
             // Get adapter and associated IP address
-            $if = $this->node()->hardware()->api_retrieve_adapter($data['interface']);
-            $if_ip = $if->ip_address();
-            $if_prefix = netmask2cidr($if->mask());
-            $validate = cidr_match($data['gateway'], cidr2network($if_ip, $if_prefix), $if_prefix);
-            if(!$validate){
-                $this->set_form_error('gateway', 'Gateway is not on '.$data['interface'].' subnet ('.$if_ip.'/'.$if_prefix.')');
+            $if = $this->node()->hardware()->api_retrieve_adapter($interface);
+            if($if){
+                $if_ip = $if->ip_address();
+                $if_prefix = netmask2cidr($if->mask());
+                $subnet = cidr_match($data['gateway'], cidr2network($if_ip, $if_prefix), $if_prefix);
+                if(!$subnet){
+                    $validate = false;
+                    $output['gateway']= 'Gateway is not on '.$data['interface'].'subnet ('.$if_ip.'/'.$if_prefix.')';
+                    $this->set_form_error('gateway', $output['gateway']);
+                }
             }
         }
 
