@@ -1106,8 +1106,8 @@ class Iface extends Network
 			$info['PROVIDER'] = 'DSL' . $eth;
 			$info['USER'] = $username;
 
-			if (!$peerdns)
-				$info['PEERDNS'] = 'no';
+			/* if (!$peerdns)
+              $info['PEERDNS'] = 'no'; */
 
 			if (!empty($mtu))
 				$info['MTU'] = $mtu;
@@ -1199,7 +1199,7 @@ class Iface extends Network
 				$info['BOOTPROTO'] = 'dhcp';
 				if (strlen($hostname))
 					$info['DHCP_HOSTNAME'] = $hostname;
-				$info['PEERDNS'] = ($peerdns) ? "yes" : "no";
+				//$info['PEERDNS'] = ($peerdns) ? "yes" : "no";
 			} else {
 				$info['BOOTPROTO'] = 'static';
 				$info['IPADDR'] = $ip;
@@ -1284,7 +1284,7 @@ class Iface extends Network
 				$info['BOOTPROTO'] = 'dhcp';
 				if (strlen($hostname))
 					$info['DHCP_HOSTNAME'] = $hostname;
-				$info['PEERDNS'] = ($peerdns) ? "yes" : "no";
+				//$info['PEERDNS'] = ($peerdns) ? "yes" : "no";
 			} else {
 				$info['BOOTPROTO'] = 'static';
 				$info['IPADDR'] = $ip;
@@ -1425,7 +1425,7 @@ class Iface extends Network
 
 			if ($isdhcp) {
 				$info['BOOTPROTO'] = 'dhcp';
-				$info['PEERDNS'] = ($peerdns) ? "yes" : "no";
+				//$info['PEERDNS'] = ($peerdns) ? "yes" : "no";
 			} else {
 				$info['BOOTPROTO'] = 'static';
 				$info['IPADDR'] = $ip;
