@@ -1174,7 +1174,12 @@ function WebAuthenticate()
       require_once(COMMON_CORE_DIR . '/api/ShellExec.class.php');
       $shell = new ShellExec();
       $cmd = '/usr/local/sng/bin/sng-user-mgmt';
-      $args =' --action=login --user='.$username.' --password='.$password;
+      if(!defined('BASEPATH')){
+	define('BASEPATH','');// for safe_helper.php passby direct script access check
+      }
+      require_once(COMMON_CORE_DIR . '/SAFe/application/helpers/safe_helper.php');
+      $string = safe_aes_encrypt($password, safe_aes_getkey($username));
+      $args =' --action=login --user='.$username.' --encrypted-password="' . $string.'"';
       $rc = $shell->Execute($cmd, $args, true, array('log'));
       if(0 == $rc){
         Logger::SysLog("webconfig", "login - ".$username." login successful");
